@@ -7,7 +7,6 @@ import (
 	"time"
 
 	"github.com/cloudskiff/driftctl/pkg/resource"
-	testresource "github.com/cloudskiff/driftctl/test/resource"
 	"github.com/r3labs/diff/v2"
 	"github.com/stretchr/testify/assert"
 
@@ -42,7 +41,7 @@ func TestHTML_Write(t *testing.T) {
 				a.Date = time.Date(2021, 06, 10, 0, 0, 0, 0, &time.Location{})
 				a.Duration = 72 * time.Second
 				a.AddManaged(
-					&testresource.FakeResource{
+					&resource.Resource{
 						Id:   "deleted-id-3",
 						Type: "aws_deleted_resource",
 					},
@@ -56,51 +55,82 @@ func TestHTML_Write(t *testing.T) {
 		{
 			name:       "test html output",
 			goldenfile: "output.html",
-
 			analysis: func() *analyser.Analysis {
 				a := fakeAnalysisWithAlerts()
 				a.Date = time.Date(2021, 06, 10, 0, 0, 0, 0, &time.Location{})
 				a.Duration = 91 * time.Second
+				a.AddManaged(
+					&resource.Resource{
+						Id:   "diff-id-2",
+						Type: "aws_diff_resource",
+						Source: &resource.TerraformStateSource{
+							State:  "tfstate://state.tfstate",
+							Name:   "diff-id-2",
+							Module: "module",
+						},
+					},
+					&resource.Resource{
+						Id:   "diff-id-3",
+						Type: "aws_diff_resource",
+						Source: &resource.TerraformStateSource{
+							State: "tfstate+s3://state2.tfstate",
+							Name:  "b",
+						},
+					},
+				)
 				a.AddDeleted(
-					&testresource.FakeResource{
+					&resource.Resource{
 						Id:   "deleted-id-3",
 						Type: "aws_deleted_resource",
+						Source: &resource.TerraformStateSource{
+							State: "tfstate://deleted/terraform.tfstate",
+							Name:  "deleted-id-3",
+						},
 					},
-					&testresource.FakeResource{
+					&resource.Resource{
 						Id:   "deleted-id-4",
 						Type: "aws_deleted_resource",
+						Source: &resource.TerraformStateSource{
+							State: "tfstate://deleted/terraform.tfstate",
+							Name:  "deleted-id-3",
+						},
 					},
-					&testresource.FakeResource{
+					&resource.Resource{
 						Id:   "deleted-id-5",
 						Type: "aws_deleted_resource",
+						Source: &resource.TerraformStateSource{
+							State:  "tfstate://deleted/terraform.tfstate",
+							Name:   "deleted-id-3",
+							Module: "module-1",
+						},
 					},
-					&testresource.FakeResource{
+					&resource.Resource{
 						Id:   "deleted-id-6",
 						Type: "aws_deleted_resource",
 					},
 				)
 				a.AddUnmanaged(
-					&testresource.FakeResource{
+					&resource.Resource{
 						Id:   "unmanaged-id-3",
 						Type: "aws_unmanaged_resource",
 					},
-					&testresource.FakeResource{
+					&resource.Resource{
 						Id:   "unmanaged-id-4",
 						Type: "aws_unmanaged_resource",
 					},
-					&testresource.FakeResource{
+					&resource.Resource{
 						Id:   "unmanaged-id-5",
 						Type: "aws_unmanaged_resource",
 					},
 				)
 				a.AddDifference(analyser.Difference{
-					Res: &resource.AbstractResource{
+					Res: &resource.Resource{
 						Id:   "diff-id-2",
 						Type: "aws_diff_resource",
 						Source: &resource.TerraformStateSource{
 							State:  "tfstate://state.tfstate",
+							Name:   "diff-id-2",
 							Module: "module",
-							Name:   "name",
 						},
 					}, Changelog: []analyser.Change{
 						{
@@ -128,11 +158,12 @@ func TestHTML_Write(t *testing.T) {
 							},
 						},
 						{
+							JsonString: true,
 							Change: diff.Change{
 								Type: diff.UPDATE,
-								Path: []string{"Policies", "0"},
-								From: testresource.FakeResource{},
-								To:   testresource.FakeResource{Id: "093cd6ba-cf6d-4800-b252-6a50ca8903cd", Type: "aws_iam_policy"},
+								Path: []string{"policy"},
+								From: `{"Statement":[{"Action":["s3:GetObjectVersion"],"Effect":"Allow","Principal":"*","Resource":"arn:aws:s3:::tmxxrn.foobar.driftctl-test.com/*","Sid":"PublicRead"}],"Version":"2012-10-17"}`,
+								To:   `{"Statement":[{"Action":["*"],"Effect":"Deny","Principal":"*","Resource":"arn:aws:s3:::tmxxrn.foobar.driftctl-test.com/b/*","Sid":"PublicReadWrite"},{"Effect":"Deny","Sid":"PublicReadWrite"}],"Version":"2021-10-17","Test":[]}`,
 							},
 						},
 						{
@@ -158,6 +189,49 @@ func TestHTML_Write(t *testing.T) {
 			},
 			err: nil,
 		},
+		{
+			name:       "test html output when coverage is 100",
+			goldenfile: "output_coverage_100.html",
+			analysis: func() *analyser.Analysis {
+				a := &analyser.Analysis{}
+				a.Date = time.Date(2021, 06, 10, 0, 0, 0, 0, &time.Location{})
+				a.Duration = 91 * time.Second
+				a.AddManaged(
+					&resource.Resource{
+						Id:   "resource-id-1",
+						Type: "aws_resource",
+						Source: &resource.TerraformStateSource{
+							State:  "tfstate://state.tfstate",
+							Module: "module",
+							Name:   "name",
+						},
+					},
+				)
+				a.AddDifference(analyser.Difference{
+					Res: &resource.Resource{
+						Id:   "resource-id-1",
+						Type: "aws_resource",
+						Source: &resource.TerraformStateSource{
+							State:  "tfstate://state.tfstate",
+							Module: "module",
+							Name:   "name",
+						},
+					}, Changelog: []analyser.Change{
+						{
+							Change: diff.Change{
+								Type: diff.DELETE,
+								Path: []string{"path", "to", "fields", "0"},
+								From: "value",
+								To:   nil,
+							},
+						},
+					}})
+				a.ProviderName = "AWS"
+				a.ProviderVersion = "3.19.0"
+				return a
+			},
+			err: nil,
+		},
 	}
 	for _, tt := range tests {
 		t.Run(tt.name, func(t *testing.T) {
@@ -201,34 +275,34 @@ func TestHTML_Write(t *testing.T) {
 func TestHTML_DistinctResourceTypes(t *testing.T) {
 	tests := []struct {
 		name      string
-		resources []resource.Resource
+		resources []*resource.Resource
 		value     []string
 	}{
 		{
-			name:      "test empty array",
-			resources: []resource.Resource{},
+			name:      "should return empty array",
+			resources: []*resource.Resource{},
 			value:     []string{},
 		},
 		{
-			name: "test empty array",
-			resources: []resource.Resource{
-				&testresource.FakeResource{
+			name: "should return distinct list of resource types",
+			resources: []*resource.Resource{
+				{
 					Id:   "deleted-id-1",
 					Type: "aws_deleted_resource",
 				},
-				&testresource.FakeResource{
+				{
 					Id:   "unmanaged-id-1",
 					Type: "aws_unmanaged_resource",
 				},
-				&testresource.FakeResource{
+				{
 					Id:   "unmanaged-id-2",
 					Type: "aws_unmanaged_resource",
 				},
-				&testresource.FakeResource{
+				{
 					Id:   "diff-id-1",
 					Type: "aws_diff_resource",
 				},
-				&testresource.FakeResource{
+				{
 					Id:   "deleted-id-2",
 					Type: "aws_deleted_resource",
 				},
@@ -243,3 +317,69 @@ func TestHTML_DistinctResourceTypes(t *testing.T) {
 		})
 	}
 }
+
+func TestHTML_DistinctIaCSources(t *testing.T) {
+	tests := []struct {
+		name      string
+		resources []*resource.Resource
+		value     []string
+	}{
+		{
+			name:      "should return empty array",
+			resources: []*resource.Resource{},
+			value:     []string{},
+		},
+		{
+			name: "should return distinct list of iac sources",
+			resources: []*resource.Resource{
+				{
+					Id:   "deleted-id-1",
+					Type: "aws_deleted_resource",
+					Source: &resource.TerraformStateSource{
+						Module: "module",
+						Name:   "test",
+						State:  "tfstate://terraform.tfstate",
+					},
+				},
+				{
+					Id:   "unmanaged-id-1",
+					Type: "aws_unmanaged_resource",
+					Source: &resource.TerraformStateSource{
+						Module: "module",
+						Name:   "test",
+						State:  "tfstate://terraform2.tfstate",
+					},
+				},
+				{
+					Id:   "unmanaged-id-2",
+					Type: "aws_unmanaged_resource",
+					Source: &resource.TerraformStateSource{
+						Module: "module",
+						Name:   "test",
+						State:  "tfstate+s3://test/terraform.tfstate",
+					},
+				},
+				{
+					Id:   "diff-id-1",
+					Type: "aws_diff_resource",
+					Source: &resource.TerraformStateSource{
+						Module: "module",
+						Name:   "test",
+						State:  "tfstate://terraform.tfstate",
+					},
+				},
+				{
+					Id:   "deleted-id-2",
+					Type: "aws_deleted_resource",
+				},
+			},
+			value: []string{"tfstate://terraform.tfstate", "tfstate://terraform2.tfstate", "tfstate+s3://test/terraform.tfstate"},
+		},
+	}
+	for _, tt := range tests {
+		t.Run(tt.name, func(t *testing.T) {
+			got := distinctIaCSources(tt.resources)
+			assert.Equal(t, tt.value, got)
+		})
+	}
+}
