@@ -10,43 +10,66 @@ import (
 	"github.com/cloudskiff/driftctl/pkg/output"
 	"github.com/cloudskiff/driftctl/pkg/remote/alerts"
 	"github.com/cloudskiff/driftctl/pkg/remote/common"
+	remoteerr "github.com/cloudskiff/driftctl/pkg/remote/error"
 	"github.com/cloudskiff/driftctl/pkg/resource"
-	testresource "github.com/cloudskiff/driftctl/test/resource"
+	"github.com/pkg/errors"
 	"github.com/r3labs/diff/v2"
 )
 
 func fakeAnalysis() *analyser.Analysis {
 	a := analyser.Analysis{}
 	a.AddUnmanaged(
-		&testresource.FakeResource{
+		&resource.Resource{
 			Id:   "unmanaged-id-1",
 			Type: "aws_unmanaged_resource",
 		},
-		&testresource.FakeResource{
+		&resource.Resource{
 			Id:   "unmanaged-id-2",
 			Type: "aws_unmanaged_resource",
 		},
 	)
 	a.AddDeleted(
-		&testresource.FakeResource{
+		&resource.Resource{
 			Id:   "deleted-id-1",
 			Type: "aws_deleted_resource",
-		}, &testresource.FakeResource{
+			Source: &resource.TerraformStateSource{
+				State:  "tfstate://delete_state.tfstate",
+				Module: "module",
+				Name:   "name",
+			},
+		}, &resource.Resource{
 			Id:   "deleted-id-2",
 			Type: "aws_deleted_resource",
 		},
 	)
 	a.AddManaged(
-		&testresource.FakeResource{
+		&resource.Resource{
 			Id:   "diff-id-1",
 			Type: "aws_diff_resource",
 		},
-		&testresource.FakeResource{
+		&resource.Resource{
 			Id:   "no-diff-id-1",
 			Type: "aws_no_diff_resource",
 		},
 	)
-	a.AddDifference(analyser.Difference{Res: &resource.AbstractResource{
+	// Cover the case when a diff occur on a resource without a source
+	a.AddDifference(analyser.Difference{
+		Res: &resource.Resource{
+			Id:   "diff-id-2",
+			Type: "aws_diff_resource",
+		},
+		Changelog: []analyser.Change{
+			{
+				Change: diff.Change{
+					Type: diff.UPDATE,
+					Path: []string{"updated", "field"},
+					From: "foobar",
+					To:   "barfoo",
+				},
+			},
+		},
+	})
+	a.AddDifference(analyser.Difference{Res: &resource.Resource{
 		Id:   "diff-id-1",
 		Type: "aws_diff_resource",
 		Source: &resource.TerraformStateSource{
@@ -90,9 +113,9 @@ func fakeAnalysisWithAlerts() *analyser.Analysis {
 	a := fakeAnalysis()
 	a.SetAlerts(alerter.Alerts{
 		"": []alerter.Alert{
-			alerts.NewRemoteAccessDeniedAlert(common.RemoteAWSTerraform, "aws_vpc", "aws_vpc", alerts.EnumerationPhase),
-			alerts.NewRemoteAccessDeniedAlert(common.RemoteAWSTerraform, "aws_sqs", "aws_sqs", alerts.EnumerationPhase),
-			alerts.NewRemoteAccessDeniedAlert(common.RemoteAWSTerraform, "aws_sns", "aws_sns", alerts.EnumerationPhase),
+			alerts.NewRemoteAccessDeniedAlert(common.RemoteAWSTerraform, remoteerr.NewResourceListingErrorWithType(errors.New("dummy error"), "aws_vpc", "aws_vpc"), alerts.EnumerationPhase),
+			alerts.NewRemoteAccessDeniedAlert(common.RemoteAWSTerraform, remoteerr.NewResourceListingErrorWithType(errors.New("dummy error"), "aws_sqs", "aws_sqs"), alerts.EnumerationPhase),
+			alerts.NewRemoteAccessDeniedAlert(common.RemoteAWSTerraform, remoteerr.NewResourceListingErrorWithType(errors.New("dummy error"), "aws_sns", "aws_sns"), alerts.EnumerationPhase),
 		},
 	})
 	a.ProviderVersion = "3.19.0"
@@ -102,7 +125,7 @@ func fakeAnalysisWithAlerts() *analyser.Analysis {
 func fakeAnalysisNoDrift() *analyser.Analysis {
 	a := analyser.Analysis{}
 	for i := 0; i < 5; i++ {
-		a.AddManaged(&testresource.FakeResource{
+		a.AddManaged(&resource.Resource{
 			Id:   "managed-id-" + fmt.Sprintf("%d", i),
 			Type: "aws_managed_resource",
 		})
@@ -115,19 +138,19 @@ func fakeAnalysisNoDrift() *analyser.Analysis {
 func fakeAnalysisWithJsonFields() *analyser.Analysis {
 	a := analyser.Analysis{}
 	a.AddManaged(
-		&testresource.FakeResource{
+		&resource.Resource{
 			Id:   "diff-id-1",
 			Type: "aws_diff_resource",
 		},
 	)
 	a.AddManaged(
-		&testresource.FakeResource{
+		&resource.Resource{
 			Id:   "diff-id-2",
 			Type: "aws_diff_resource",
 		},
 	)
 	a.AddDifference(analyser.Difference{
-		Res: &resource.AbstractResource{
+		Res: &resource.Resource{
 			Id:   "diff-id-1",
 			Type: "aws_diff_resource",
 			Source: &resource.TerraformStateSource{
@@ -148,7 +171,7 @@ func fakeAnalysisWithJsonFields() *analyser.Analysis {
 			},
 		}})
 	a.AddDifference(analyser.Difference{
-		Res: &resource.AbstractResource{
+		Res: &resource.Resource{
 			Id:   "diff-id-2",
 			Type: "aws_diff_resource",
 			Source: &resource.TerraformStateSource{
@@ -176,20 +199,28 @@ func fakeAnalysisWithJsonFields() *analyser.Analysis {
 func fakeAnalysisWithoutAttrs() *analyser.Analysis {
 	a := analyser.Analysis{}
 	a.AddDeleted(
-		&testresource.FakeResourceStringer{
+		&resource.Resource{
 			Id:    "dfjkgnbsgj",
+			Type:  "FakeResourceStringer",
 			Attrs: &resource.Attributes{},
+			Source: &resource.TerraformStateSource{
+				State:  "tfstate://state.tfstate",
+				Module: "module",
+				Name:   "name",
+			},
 		},
 	)
 	a.AddManaged(
-		&testresource.FakeResourceStringer{
+		&resource.Resource{
 			Id:    "usqyfsdbgjsdgjkdfg",
+			Type:  "FakeResourceStringer",
 			Attrs: &resource.Attributes{},
 		},
 	)
 	a.AddUnmanaged(
-		&testresource.FakeResourceStringer{
+		&resource.Resource{
 			Id:    "duysgkfdjfdgfhd",
+			Type:  "FakeResourceStringer",
 			Attrs: &resource.Attributes{},
 		},
 	)
@@ -200,45 +231,50 @@ func fakeAnalysisWithoutAttrs() *analyser.Analysis {
 
 func fakeAnalysisWithStringerResources() *analyser.Analysis {
 	a := analyser.Analysis{}
-	fakeResourceStringerSchema := &resource.Schema{HumanReadableAttributesFunc: func(res *resource.AbstractResource) map[string]string {
+	schema := &resource.Schema{HumanReadableAttributesFunc: func(res *resource.Resource) map[string]string {
 		return map[string]string{
 			"Name": (*res.Attrs)["name"].(string),
 		}
 	}}
 	a.AddDeleted(
-		&resource.AbstractResource{
+		&resource.Resource{
 			Id:   "dfjkgnbsgj",
 			Type: "FakeResourceStringer",
-			Sch:  fakeResourceStringerSchema,
+			Sch:  schema,
 			Attrs: &resource.Attributes{
 				"name": "deleted resource",
 			},
+			Source: &resource.TerraformStateSource{
+				State:  "tfstate://state.tfstate",
+				Module: "module",
+				Name:   "name",
+			},
 		},
 	)
 	a.AddManaged(
-		&resource.AbstractResource{
+		&resource.Resource{
 			Id:   "usqyfsdbgjsdgjkdfg",
 			Type: "FakeResourceStringer",
-			Sch:  fakeResourceStringerSchema,
+			Sch:  schema,
 			Attrs: &resource.Attributes{
 				"name": "managed resource",
 			},
 		},
 	)
 	a.AddUnmanaged(
-		&resource.AbstractResource{
+		&resource.Resource{
 			Id:   "duysgkfdjfdgfhd",
 			Type: "FakeResourceStringer",
-			Sch:  fakeResourceStringerSchema,
+			Sch:  schema,
 			Attrs: &resource.Attributes{
 				"name": "unmanaged resource",
 			},
 		},
 	)
-	a.AddDifference(analyser.Difference{Res: &resource.AbstractResource{
+	a.AddDifference(analyser.Difference{Res: &resource.Resource{
 		Id:   "gdsfhgkbn",
 		Type: "FakeResourceStringer",
-		Sch:  fakeResourceStringerSchema,
+		Sch:  schema,
 		Attrs: &resource.Attributes{
 			"name": "resource with diff",
 		},
@@ -265,13 +301,13 @@ func fakeAnalysisWithStringerResources() *analyser.Analysis {
 func fakeAnalysisWithComputedFields() *analyser.Analysis {
 	a := analyser.Analysis{}
 	a.AddManaged(
-		&testresource.FakeResource{
+		&resource.Resource{
 			Id:   "diff-id-1",
 			Type: "aws_diff_resource",
 		},
 	)
 	a.AddDifference(analyser.Difference{
-		Res: &resource.AbstractResource{
+		Res: &resource.Resource{
 			Id:   "diff-id-1",
 			Type: "aws_diff_resource",
 			Source: &resource.TerraformStateSource{
@@ -348,9 +384,9 @@ func fakeAnalysisWithAWSEnumerationError() *analyser.Analysis {
 	a := analyser.Analysis{}
 	a.SetAlerts(alerter.Alerts{
 		"": []alerter.Alert{
-			alerts.NewRemoteAccessDeniedAlert(common.RemoteAWSTerraform, "aws_vpc", "aws_vpc", alerts.EnumerationPhase),
-			alerts.NewRemoteAccessDeniedAlert(common.RemoteAWSTerraform, "aws_sqs", "aws_sqs", alerts.EnumerationPhase),
-			alerts.NewRemoteAccessDeniedAlert(common.RemoteAWSTerraform, "aws_sns", "aws_sns", alerts.EnumerationPhase),
+			alerts.NewRemoteAccessDeniedAlert(common.RemoteAWSTerraform, remoteerr.NewResourceListingErrorWithType(errors.New("dummy error"), "aws_vpc", "aws_vpc"), alerts.EnumerationPhase),
+			alerts.NewRemoteAccessDeniedAlert(common.RemoteAWSTerraform, remoteerr.NewResourceListingErrorWithType(errors.New("dummy error"), "aws_sqs", "aws_sqs"), alerts.EnumerationPhase),
+			alerts.NewRemoteAccessDeniedAlert(common.RemoteAWSTerraform, remoteerr.NewResourceListingErrorWithType(errors.New("dummy error"), "aws_sns", "aws_sns"), alerts.EnumerationPhase),
 		},
 	})
 	a.ProviderName = "AWS"
@@ -362,8 +398,8 @@ func fakeAnalysisWithGithubEnumerationError() *analyser.Analysis {
 	a := analyser.Analysis{}
 	a.SetAlerts(alerter.Alerts{
 		"": []alerter.Alert{
-			alerts.NewRemoteAccessDeniedAlert(common.RemoteGithubTerraform, "github_team", "github_team", alerts.EnumerationPhase),
-			alerts.NewRemoteAccessDeniedAlert(common.RemoteGithubTerraform, "github_team_membership", "github_team", alerts.EnumerationPhase),
+			alerts.NewRemoteAccessDeniedAlert(common.RemoteGithubTerraform, remoteerr.NewResourceListingErrorWithType(errors.New("dummy error"), "github_team", "github_team"), alerts.EnumerationPhase),
+			alerts.NewRemoteAccessDeniedAlert(common.RemoteGithubTerraform, remoteerr.NewResourceListingErrorWithType(errors.New("dummy error"), "github_team_membership", "github_team"), alerts.EnumerationPhase),
 		},
 	})
 	a.ProviderName = "AWS"
@@ -374,14 +410,14 @@ func fakeAnalysisWithGithubEnumerationError() *analyser.Analysis {
 func fakeAnalysisForJSONPlan() *analyser.Analysis {
 	a := analyser.Analysis{}
 	a.AddUnmanaged(
-		&resource.AbstractResource{
+		&resource.Resource{
 			Id:   "unmanaged-id-1",
 			Type: "aws_unmanaged_resource",
 			Attrs: &resource.Attributes{
 				"name": "First unmanaged resource",
 			},
 		},
-		&resource.AbstractResource{
+		&resource.Resource{
 			Id:   "unmanaged-id-2",
 			Type: "aws_unmanaged_resource",
 			Attrs: &resource.Attributes{
@@ -390,14 +426,14 @@ func fakeAnalysisForJSONPlan() *analyser.Analysis {
 		},
 	)
 	a.AddManaged(
-		&resource.AbstractResource{
+		&resource.Resource{
 			Id:   "managed-id-1",
 			Type: "aws_managed_resource",
 			Attrs: &resource.Attributes{
 				"name": "First managed resource",
 			},
 		},
-		&resource.AbstractResource{
+		&resource.Resource{
 			Id:   "managed-id-2",
 			Type: "aws_managed_resource",
 			Attrs: &resource.Attributes{
@@ -478,10 +514,8 @@ func TestGetPrinter(t *testing.T) {
 	for _, tt := range tests {
 		t.Run(tt.name, func(t *testing.T) {
 			if got := GetPrinter(OutputConfig{
-				Key: tt.key,
-				Options: map[string]string{
-					"path": tt.path,
-				},
+				Key:  tt.key,
+				Path: tt.path,
 			}, tt.quiet); !reflect.DeepEqual(got, tt.want) {
 				t.Errorf("GetPrinter() = %v, want %v", got, tt.want)
 			}
