@@ -4,6 +4,6 @@ import "github.com/cloudskiff/driftctl/pkg/resource"
 
 type Filter interface {
 	IsTypeIgnored(ty resource.ResourceType) bool
-	IsResourceIgnored(res resource.Resource) bool
-	IsFieldIgnored(res resource.Resource, path []string) bool
+	IsResourceIgnored(res *resource.Resource) bool
+	IsFieldIgnored(res *resource.Resource, path []string) bool
 }
