@@ -72,19 +72,19 @@ func TestTerraformStateReader_Source(t *testing.T) {
 	assert.Nil(t, err)
 	assert.Len(t, got, 2)
 	for _, res := range got {
-		if res.TerraformType() == resourceaws.AwsS3BucketResourceType {
+		if res.ResourceType() == resourceaws.AwsS3BucketResourceType {
 			assert.Equal(t, &resource.TerraformStateSource{
 				State:  "tfstate://test/source/terraform.tfstate",
 				Module: "",
 				Name:   "bucket",
-			}, res.(*resource.AbstractResource).Source)
+			}, res.Source)
 		}
-		if res.TerraformType() == resourceaws.AwsIamUserResourceType {
+		if res.ResourceType() == resourceaws.AwsIamUserResourceType {
 			assert.Equal(t, &resource.TerraformStateSource{
 				State:  "tfstate://test/source/terraform.tfstate",
 				Module: "module.iam_iam-user",
 				Name:   "this_no_pgp",
-			}, res.(*resource.AbstractResource).Source)
+			}, res.Source)
 		}
 	}
 }
@@ -302,7 +302,7 @@ func TestTerraformStateReader_Github_Resources(t *testing.T) {
 	}
 }
 
-func convert(got []resource.Resource) []interface{} {
+func convert(got []*resource.Resource) []interface{} {
 	unm, err := json.Marshal(got)
 	if err != nil {
 		panic(err)
