@@ -14,35 +14,32 @@ func NewS3BucketAcl() S3BucketAcl {
 	return S3BucketAcl{}
 }
 
-func (m S3BucketAcl) Execute(remoteResources, resourcesFromState *[]resource.Resource) error {
+func (m S3BucketAcl) Execute(remoteResources, resourcesFromState *[]*resource.Resource) error {
 
 	for _, iacResource := range *resourcesFromState {
 		// Ignore all resources other than s3 buckets
-		if iacResource.TerraformType() != aws.AwsS3BucketResourceType {
+		if iacResource.ResourceType() != aws.AwsS3BucketResourceType {
 			continue
 		}
 
-		decodedIacResource, _ := iacResource.(*resource.AbstractResource)
-
 		for _, remoteResource := range *remoteResources {
-			if resource.IsSameResource(remoteResource, decodedIacResource) {
-				decodedRemoteResource, _ := remoteResource.(*resource.AbstractResource)
-				aclAttr, exist := decodedIacResource.Attrs.Get("acl")
+			if remoteResource.Equal(iacResource) {
+				aclAttr, exist := iacResource.Attrs.Get("acl")
 				if !exist || aclAttr == nil || aclAttr == "" {
 					break
 				}
 				if aclAttr != "private" {
 					logrus.WithFields(logrus.Fields{
-						"type": decodedRemoteResource.TerraformType(),
-						"id":   decodedRemoteResource.TerraformId(),
+						"type": remoteResource.ResourceType(),
+						"id":   remoteResource.ResourceId(),
 					}).Debug("Found a resource to update")
-					decodedRemoteResource.Attrs.SafeDelete([]string{"grant"})
+					remoteResource.Attrs.SafeDelete([]string{"grant"})
 				}
 				break
 			}
 		}
 
-		decodedIacResource.Attrs.SafeDelete([]string{"acl"})
+		iacResource.Attrs.SafeDelete([]string{"acl"})
 	}
 
 	return nil
