@@ -14,37 +14,37 @@ func TestVPCSecurityGroupRuleSanitizer(t *testing.T) {
 
 	factory := &terraform.MockResourceFactory{}
 	factory.On("CreateAbstractResource", aws.AwsSecurityGroupRuleResourceType, "sgrule-1175318309", mock.Anything).Times(1).Return(
-		&resource.AbstractResource{
+		&resource.Resource{
 			Id:    "sgrule-1175318309",
 			Type:  aws.AwsSecurityGroupRuleResourceType,
 			Attrs: &resource.Attributes{},
 		}, nil)
 
 	factory.On("CreateAbstractResource", aws.AwsSecurityGroupRuleResourceType, "sgrule-2582518759", mock.Anything).Times(1).Return(
-		&resource.AbstractResource{
+		&resource.Resource{
 			Id:    "sgrule-2582518759",
 			Type:  aws.AwsSecurityGroupRuleResourceType,
 			Attrs: &resource.Attributes{},
 		}, nil)
 
 	factory.On("CreateAbstractResource", aws.AwsSecurityGroupRuleResourceType, "sgrule-2165103420", mock.Anything).Times(1).Return(
-		&resource.AbstractResource{
+		&resource.Resource{
 			Id:    "sgrule-2165103420",
 			Type:  aws.AwsSecurityGroupRuleResourceType,
 			Attrs: &resource.Attributes{},
 		}, nil)
 
 	factory.On("CreateAbstractResource", aws.AwsSecurityGroupRuleResourceType, "sgrule-350400929", mock.Anything).Times(1).Return(
-		&resource.AbstractResource{
+		&resource.Resource{
 			Id:    "sgrule-350400929",
 			Type:  aws.AwsSecurityGroupRuleResourceType,
 			Attrs: &resource.Attributes{},
 		}, nil)
 
 	middleware := NewVPCSecurityGroupRuleSanitizer(factory)
-	var remoteResources []resource.Resource
-	stateResources := []resource.Resource{
-		&resource.AbstractResource{
+	var remoteResources []*resource.Resource
+	stateResources := []*resource.Resource{
+		{
 			Id:   "sg-test",
 			Type: aws.AwsSecurityGroupResourceType,
 			Attrs: &resource.Attributes{
@@ -52,7 +52,7 @@ func TestVPCSecurityGroupRuleSanitizer(t *testing.T) {
 				"name": "test",
 			},
 		},
-		&resource.AbstractResource{
+		{
 			Id:   "sgrule-3970541193",
 			Type: aws.AwsSecurityGroupRuleResourceType,
 			Attrs: &resource.Attributes{
@@ -66,7 +66,7 @@ func TestVPCSecurityGroupRuleSanitizer(t *testing.T) {
 				"source_security_group_id": "sg-0254c038e32f25530",
 			},
 		},
-		&resource.AbstractResource{
+		{
 			Id:   "sgrule-845917806",
 			Type: aws.AwsSecurityGroupRuleResourceType,
 			Attrs: &resource.Attributes{
@@ -80,7 +80,7 @@ func TestVPCSecurityGroupRuleSanitizer(t *testing.T) {
 				"ipv6_cidr_blocks":  []interface{}{"::/0"},
 			},
 		},
-		&resource.AbstractResource{
+		{
 			Id:   "sgrule-294318973",
 			Type: aws.AwsSecurityGroupRuleResourceType,
 			Attrs: &resource.Attributes{
@@ -93,7 +93,7 @@ func TestVPCSecurityGroupRuleSanitizer(t *testing.T) {
 				"cidr_blocks":       []interface{}{"1.2.0.0/16", "5.6.7.0/24"},
 			},
 		},
-		&resource.AbstractResource{
+		{
 			Id:   "sgrule-2471889226",
 			Type: aws.AwsSecurityGroupRuleResourceType,
 			Attrs: &resource.Attributes{
@@ -106,7 +106,7 @@ func TestVPCSecurityGroupRuleSanitizer(t *testing.T) {
 				"prefix_list_id":    []interface{}{"pl-abb451c2"},
 			},
 		},
-		&resource.AbstractResource{
+		{
 			Id:   "sgrule-3587309474",
 			Type: aws.AwsSecurityGroupRuleResourceType,
 			Attrs: &resource.Attributes{
