@@ -23,13 +23,13 @@ func (e *EC2RouteEnumerator) SupportedType() resource.ResourceType {
 	return aws.AwsRouteResourceType
 }
 
-func (e *EC2RouteEnumerator) Enumerate() ([]resource.Resource, error) {
+func (e *EC2RouteEnumerator) Enumerate() ([]*resource.Resource, error) {
 	routeTables, err := e.repository.ListAllRouteTables()
 	if err != nil {
 		return nil, remoteerror.NewResourceListingErrorWithType(err, string(e.SupportedType()), aws.AwsRouteTableResourceType)
 	}
 
-	var results []resource.Resource
+	var results []*resource.Resource
 
 	for _, routeTable := range routeTables {
 		for _, route := range routeTable.Routes {
