@@ -23,13 +23,13 @@ func (e *ECRRepositoryEnumerator) SupportedType() resource.ResourceType {
 	return aws.AwsEcrRepositoryResourceType
 }
 
-func (e *ECRRepositoryEnumerator) Enumerate() ([]resource.Resource, error) {
+func (e *ECRRepositoryEnumerator) Enumerate() ([]*resource.Resource, error) {
 	repos, err := e.repository.ListAllRepositories()
 	if err != nil {
 		return nil, remoteerror.NewResourceListingError(err, string(e.SupportedType()))
 	}
 
-	results := make([]resource.Resource, len(repos))
+	results := make([]*resource.Resource, len(repos))
 
 	for _, repo := range repos {
 		results = append(
