@@ -299,7 +299,7 @@ func Test_ec2Repository_ListAllAddressesAssociation(t *testing.T) {
 	tests := []struct {
 		name    string
 		mocks   func(client *awstest.MockFakeEC2)
-		want    []string
+		want    []*ec2.Address
 		wantErr error
 	}{
 		{
@@ -315,11 +315,11 @@ func Test_ec2Repository_ListAllAddressesAssociation(t *testing.T) {
 						},
 					}, nil).Once()
 			},
-			want: []string{
-				"1",
-				"2",
-				"3",
-				"4",
+			want: []*ec2.Address{
+				{AssociationId: aws.String("1")},
+				{AssociationId: aws.String("2")},
+				{AssociationId: aws.String("3")},
+				{AssociationId: aws.String("4")},
 			},
 		},
 	}
@@ -340,7 +340,7 @@ func Test_ec2Repository_ListAllAddressesAssociation(t *testing.T) {
 				cachedData, err := r.ListAllAddressesAssociation()
 				assert.NoError(t, err)
 				assert.Equal(t, got, cachedData)
-				assert.IsType(t, []string{}, store.Get("ec2ListAllAddressesAssociation"))
+				assert.IsType(t, []*ec2.Address{}, store.Get("ec2ListAllAddressesAssociation"))
 			}
 
 			changelog, err := diff.Diff(got, tt.want)
@@ -365,7 +365,20 @@ func Test_ec2Repository_ListAllInstances(t *testing.T) {
 		{name: "List with 2 pages",
 			mocks: func(client *awstest.MockFakeEC2) {
 				client.On("DescribeInstancesPages",
-					&ec2.DescribeInstancesInput{},
+					&ec2.DescribeInstancesInput{
+						Filters: []*ec2.Filter{
+							{
+								Name: aws.String("instance-state-name"),
+								Values: aws.StringSlice([]string{
+									"pending",
+									"running",
+									"stopping",
+									"shutting-down",
+									"stopped",
+								}),
+							},
+						},
+					},
 					mock.MatchedBy(func(callback func(res *ec2.DescribeInstancesOutput, lastPage bool) bool) bool {
 						callback(&ec2.DescribeInstancesOutput{
 							Reservations: []*ec2.Reservation{
