@@ -9,10 +9,12 @@ import (
 	"github.com/aws/aws-sdk-go/service/iam"
 	"github.com/cloudskiff/driftctl/mocks"
 	"github.com/cloudskiff/driftctl/pkg/filter"
+	"github.com/cloudskiff/driftctl/pkg/remote/alerts"
 	remoteaws "github.com/cloudskiff/driftctl/pkg/remote/aws"
 	"github.com/cloudskiff/driftctl/pkg/remote/aws/repository"
 	"github.com/cloudskiff/driftctl/pkg/remote/cache"
 	"github.com/cloudskiff/driftctl/pkg/remote/common"
+	remoteerr "github.com/cloudskiff/driftctl/pkg/remote/error"
 	"github.com/cloudskiff/driftctl/pkg/resource"
 	resourceaws "github.com/cloudskiff/driftctl/pkg/resource/aws"
 	"github.com/cloudskiff/driftctl/pkg/terraform"
@@ -20,6 +22,7 @@ import (
 	"github.com/cloudskiff/driftctl/test/goldenfile"
 	testresource "github.com/cloudskiff/driftctl/test/resource"
 	terraform2 "github.com/cloudskiff/driftctl/test/terraform"
+	"github.com/pkg/errors"
 	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/mock"
 )
@@ -29,13 +32,13 @@ func TestIamUser(t *testing.T) {
 	cases := []struct {
 		test    string
 		dirName string
-		mocks   func(repo *repository.MockIAMRepository)
+		mocks   func(*repository.MockIAMRepository, *mocks.AlerterInterface)
 		wantErr error
 	}{
 		{
 			test:    "no iam user",
 			dirName: "iam_user_empty",
-			mocks: func(repo *repository.MockIAMRepository) {
+			mocks: func(repo *repository.MockIAMRepository, alerter *mocks.AlerterInterface) {
 				repo.On("ListAllUsers").Return([]*iam.User{}, nil)
 			},
 			wantErr: nil,
@@ -43,7 +46,7 @@ func TestIamUser(t *testing.T) {
 		{
 			test:    "iam multiples users",
 			dirName: "iam_user_multiple",
-			mocks: func(repo *repository.MockIAMRepository) {
+			mocks: func(repo *repository.MockIAMRepository, alerter *mocks.AlerterInterface) {
 				repo.On("ListAllUsers").Return([]*iam.User{
 					{
 						UserName: aws.String("test-driftctl-0"),
@@ -61,8 +64,11 @@ func TestIamUser(t *testing.T) {
 		{
 			test:    "cannot list iam user",
 			dirName: "iam_user_empty",
-			mocks: func(repo *repository.MockIAMRepository) {
-				repo.On("ListAllUsers").Return(nil, awserr.NewRequestFailure(nil, 403, ""))
+			mocks: func(repo *repository.MockIAMRepository, alerter *mocks.AlerterInterface) {
+				awsError := awserr.NewRequestFailure(awserr.New("AccessDeniedException", "", errors.New("")), 403, "")
+				repo.On("ListAllUsers").Return(nil, awsError)
+
+				alerter.On("SendAlert", resourceaws.AwsIamUserResourceType, alerts.NewRemoteAccessDeniedAlert(common.RemoteAWSTerraform, remoteerr.NewResourceListingErrorWithType(awsError, resourceaws.AwsIamUserResourceType, resourceaws.AwsIamUserResourceType), alerts.EnumerationPhase)).Return()
 			},
 			wantErr: nil,
 		},
@@ -86,9 +92,9 @@ func TestIamUser(t *testing.T) {
 
 			// Initialize mocks
 			alerter := &mocks.AlerterInterface{}
-			alerter.On("SendAlert", mock.Anything, mock.Anything).Maybe().Return()
 			fakeRepo := &repository.MockIAMRepository{}
-			c.mocks(fakeRepo)
+			c.mocks(fakeRepo, alerter)
+
 			var repo repository.IAMRepository = fakeRepo
 			providerVersion := "3.19.0"
 			realProvider, err := terraform2.InitTestAwsProvider(providerLibrary, providerVersion)
@@ -121,6 +127,8 @@ func TestIamUser(t *testing.T) {
 				return
 			}
 			test.TestAgainstGoldenFile(got, resourceaws.AwsIamUserResourceType, c.dirName, provider, deserializer, shouldUpdate, tt)
+			alerter.AssertExpectations(tt)
+			fakeRepo.AssertExpectations(tt)
 		})
 	}
 }
@@ -130,13 +138,13 @@ func TestIamUserPolicy(t *testing.T) {
 	cases := []struct {
 		test    string
 		dirName string
-		mocks   func(repo *repository.MockIAMRepository)
+		mocks   func(*repository.MockIAMRepository, *mocks.AlerterInterface)
 		wantErr error
 	}{
 		{
 			test:    "no iam user policy",
 			dirName: "iam_user_policy_empty",
-			mocks: func(repo *repository.MockIAMRepository) {
+			mocks: func(repo *repository.MockIAMRepository, alerter *mocks.AlerterInterface) {
 				users := []*iam.User{
 					{
 						UserName: aws.String("loadbalancer"),
@@ -150,7 +158,7 @@ func TestIamUserPolicy(t *testing.T) {
 		{
 			test:    "iam multiples users multiple policies",
 			dirName: "iam_user_policy_multiple",
-			mocks: func(repo *repository.MockIAMRepository) {
+			mocks: func(repo *repository.MockIAMRepository, alerter *mocks.AlerterInterface) {
 				users := []*iam.User{
 					{
 						UserName: aws.String("loadbalancer"),
@@ -183,17 +191,23 @@ func TestIamUserPolicy(t *testing.T) {
 		{
 			test:    "cannot list user",
 			dirName: "iam_user_policy_empty",
-			mocks: func(repo *repository.MockIAMRepository) {
-				repo.On("ListAllUsers").Return(nil, awserr.NewRequestFailure(nil, 403, ""))
+			mocks: func(repo *repository.MockIAMRepository, alerter *mocks.AlerterInterface) {
+				awsError := awserr.NewRequestFailure(awserr.New("AccessDeniedException", "", errors.New("")), 403, "")
+				repo.On("ListAllUsers").Return(nil, awsError)
+
+				alerter.On("SendAlert", resourceaws.AwsIamUserPolicyResourceType, alerts.NewRemoteAccessDeniedAlert(common.RemoteAWSTerraform, remoteerr.NewResourceListingErrorWithType(awsError, resourceaws.AwsIamUserPolicyResourceType, resourceaws.AwsIamUserResourceType), alerts.EnumerationPhase)).Return()
 			},
 			wantErr: nil,
 		},
 		{
 			test:    "cannot list user policy",
 			dirName: "iam_user_policy_empty",
-			mocks: func(repo *repository.MockIAMRepository) {
+			mocks: func(repo *repository.MockIAMRepository, alerter *mocks.AlerterInterface) {
 				repo.On("ListAllUsers").Once().Return([]*iam.User{}, nil)
-				repo.On("ListAllUserPolicies", mock.Anything).Return(nil, awserr.NewRequestFailure(nil, 403, ""))
+				awsError := awserr.NewRequestFailure(awserr.New("AccessDeniedException", "", errors.New("")), 403, "")
+				repo.On("ListAllUserPolicies", mock.Anything).Return(nil, awsError)
+
+				alerter.On("SendAlert", resourceaws.AwsIamUserPolicyResourceType, alerts.NewRemoteAccessDeniedAlert(common.RemoteAWSTerraform, remoteerr.NewResourceListingErrorWithType(awsError, resourceaws.AwsIamUserPolicyResourceType, resourceaws.AwsIamUserPolicyResourceType), alerts.EnumerationPhase)).Return()
 			},
 			wantErr: nil,
 		},
@@ -217,9 +231,9 @@ func TestIamUserPolicy(t *testing.T) {
 
 			// Initialize mocks
 			alerter := &mocks.AlerterInterface{}
-			alerter.On("SendAlert", mock.Anything, mock.Anything).Maybe().Return()
 			fakeRepo := &repository.MockIAMRepository{}
-			c.mocks(fakeRepo)
+			c.mocks(fakeRepo, alerter)
+
 			var repo repository.IAMRepository = fakeRepo
 			providerVersion := "3.19.0"
 			realProvider, err := terraform2.InitTestAwsProvider(providerLibrary, providerVersion)
@@ -252,6 +266,8 @@ func TestIamUserPolicy(t *testing.T) {
 				return
 			}
 			test.TestAgainstGoldenFile(got, resourceaws.AwsIamUserPolicyResourceType, c.dirName, provider, deserializer, shouldUpdate, tt)
+			alerter.AssertExpectations(tt)
+			fakeRepo.AssertExpectations(tt)
 		})
 	}
 }
@@ -261,13 +277,13 @@ func TestIamPolicy(t *testing.T) {
 	cases := []struct {
 		test    string
 		dirName string
-		mocks   func(repo *repository.MockIAMRepository)
+		mocks   func(*repository.MockIAMRepository, *mocks.AlerterInterface)
 		wantErr error
 	}{
 		{
 			test:    "no iam custom policies",
 			dirName: "iam_policy_empty",
-			mocks: func(repo *repository.MockIAMRepository) {
+			mocks: func(repo *repository.MockIAMRepository, alerter *mocks.AlerterInterface) {
 				repo.On("ListAllPolicies").Once().Return([]*iam.Policy{}, nil)
 			},
 			wantErr: nil,
@@ -275,7 +291,7 @@ func TestIamPolicy(t *testing.T) {
 		{
 			test:    "iam multiples custom policies",
 			dirName: "iam_policy_multiple",
-			mocks: func(repo *repository.MockIAMRepository) {
+			mocks: func(repo *repository.MockIAMRepository, alerter *mocks.AlerterInterface) {
 				repo.On("ListAllPolicies").Once().Return([]*iam.Policy{
 					{
 						Arn: aws.String("arn:aws:iam::929327065333:policy/policy-0"),
@@ -293,8 +309,11 @@ func TestIamPolicy(t *testing.T) {
 		{
 			test:    "cannot list iam custom policies",
 			dirName: "iam_policy_empty",
-			mocks: func(repo *repository.MockIAMRepository) {
-				repo.On("ListAllPolicies").Once().Return(nil, awserr.NewRequestFailure(nil, 403, ""))
+			mocks: func(repo *repository.MockIAMRepository, alerter *mocks.AlerterInterface) {
+				awsError := awserr.NewRequestFailure(awserr.New("AccessDeniedException", "", errors.New("")), 403, "")
+				repo.On("ListAllPolicies").Once().Return(nil, awsError)
+
+				alerter.On("SendAlert", resourceaws.AwsIamPolicyResourceType, alerts.NewRemoteAccessDeniedAlert(common.RemoteAWSTerraform, remoteerr.NewResourceListingErrorWithType(awsError, resourceaws.AwsIamPolicyResourceType, resourceaws.AwsIamPolicyResourceType), alerts.EnumerationPhase)).Return()
 			},
 			wantErr: nil,
 		},
@@ -319,9 +338,9 @@ func TestIamPolicy(t *testing.T) {
 
 			// Initialize mocks
 			alerter := &mocks.AlerterInterface{}
-			alerter.On("SendAlert", mock.Anything, mock.Anything).Maybe().Return()
 			fakeRepo := &repository.MockIAMRepository{}
-			c.mocks(fakeRepo)
+			c.mocks(fakeRepo, alerter)
+
 			var repo repository.IAMRepository = fakeRepo
 			providerVersion := "3.19.0"
 			realProvider, err := terraform2.InitTestAwsProvider(providerLibrary, providerVersion)
@@ -354,6 +373,8 @@ func TestIamPolicy(t *testing.T) {
 				return
 			}
 			test.TestAgainstGoldenFile(got, resourceaws.AwsIamPolicyResourceType, c.dirName, provider, deserializer, shouldUpdate, tt)
+			alerter.AssertExpectations(tt)
+			fakeRepo.AssertExpectations(tt)
 		})
 	}
 }
@@ -363,13 +384,13 @@ func TestIamRole(t *testing.T) {
 	cases := []struct {
 		test    string
 		dirName string
-		mocks   func(repo *repository.MockIAMRepository)
+		mocks   func(*repository.MockIAMRepository, *mocks.AlerterInterface)
 		wantErr error
 	}{
 		{
 			test:    "no iam roles",
 			dirName: "iam_role_empty",
-			mocks: func(repo *repository.MockIAMRepository) {
+			mocks: func(repo *repository.MockIAMRepository, alerter *mocks.AlerterInterface) {
 				repo.On("ListAllRoles").Return([]*iam.Role{}, nil)
 			},
 			wantErr: nil,
@@ -377,7 +398,7 @@ func TestIamRole(t *testing.T) {
 		{
 			test:    "iam multiples roles",
 			dirName: "iam_role_multiple",
-			mocks: func(repo *repository.MockIAMRepository) {
+			mocks: func(repo *repository.MockIAMRepository, alerter *mocks.AlerterInterface) {
 				repo.On("ListAllRoles").Return([]*iam.Role{
 					{
 						RoleName: aws.String("test_role_0"),
@@ -398,7 +419,7 @@ func TestIamRole(t *testing.T) {
 		{
 			test:    "iam roles ignore services roles",
 			dirName: "iam_role_ignore_services_roles",
-			mocks: func(repo *repository.MockIAMRepository) {
+			mocks: func(repo *repository.MockIAMRepository, alerter *mocks.AlerterInterface) {
 				repo.On("ListAllRoles").Return([]*iam.Role{
 					{
 						RoleName: aws.String("AWSServiceRoleForOrganizations"),
@@ -437,9 +458,9 @@ func TestIamRole(t *testing.T) {
 
 			// Initialize mocks
 			alerter := &mocks.AlerterInterface{}
-			alerter.On("SendAlert", mock.Anything, mock.Anything).Maybe().Return()
 			fakeRepo := &repository.MockIAMRepository{}
-			c.mocks(fakeRepo)
+			c.mocks(fakeRepo, alerter)
+
 			var repo repository.IAMRepository = fakeRepo
 			providerVersion := "3.19.0"
 			realProvider, err := terraform2.InitTestAwsProvider(providerLibrary, providerVersion)
@@ -472,6 +493,8 @@ func TestIamRole(t *testing.T) {
 				return
 			}
 			test.TestAgainstGoldenFile(got, resourceaws.AwsIamRoleResourceType, c.dirName, provider, deserializer, shouldUpdate, tt)
+			alerter.AssertExpectations(tt)
+			fakeRepo.AssertExpectations(tt)
 		})
 	}
 }
@@ -481,13 +504,13 @@ func TestIamRolePolicyAttachment(t *testing.T) {
 	cases := []struct {
 		test    string
 		dirName string
-		mocks   func(repo *repository.MockIAMRepository)
+		mocks   func(*repository.MockIAMRepository, *mocks.AlerterInterface)
 		err     error
 	}{
 		{
 			test:    "no iam role policy",
 			dirName: "aws_iam_role_policy_empty",
-			mocks: func(repo *repository.MockIAMRepository) {
+			mocks: func(repo *repository.MockIAMRepository, alerter *mocks.AlerterInterface) {
 				roles := []*iam.Role{
 					{
 						RoleName: aws.String("test-role"),
@@ -501,7 +524,7 @@ func TestIamRolePolicyAttachment(t *testing.T) {
 		{
 			test:    "iam multiples roles multiple policies",
 			dirName: "aws_iam_role_policy_attachment_multiple",
-			mocks: func(repo *repository.MockIAMRepository) {
+			mocks: func(repo *repository.MockIAMRepository, alerter *mocks.AlerterInterface) {
 				roles := []*iam.Role{
 					{
 						RoleName: aws.String("test-role"),
@@ -561,7 +584,7 @@ func TestIamRolePolicyAttachment(t *testing.T) {
 		{
 			test:    "iam multiples roles for ignored roles",
 			dirName: "aws_iam_role_policy_attachment_empty",
-			mocks: func(repo *repository.MockIAMRepository) {
+			mocks: func(repo *repository.MockIAMRepository, alerter *mocks.AlerterInterface) {
 				roles := []*iam.Role{
 					{
 						RoleName: aws.String("AWSServiceRoleForSupport"),
@@ -579,16 +602,22 @@ func TestIamRolePolicyAttachment(t *testing.T) {
 		{
 			test:    "Cannot list roles",
 			dirName: "aws_iam_role_policy_attachment_empty",
-			mocks: func(repo *repository.MockIAMRepository) {
-				repo.On("ListAllRoles").Once().Return(nil, awserr.NewRequestFailure(nil, 403, ""))
+			mocks: func(repo *repository.MockIAMRepository, alerter *mocks.AlerterInterface) {
+				awsError := awserr.NewRequestFailure(awserr.New("AccessDeniedException", "", errors.New("")), 403, "")
+				repo.On("ListAllRoles").Once().Return(nil, awsError)
+
+				alerter.On("SendAlert", resourceaws.AwsIamRolePolicyAttachmentResourceType, alerts.NewRemoteAccessDeniedAlert(common.RemoteAWSTerraform, remoteerr.NewResourceListingErrorWithType(awsError, resourceaws.AwsIamRolePolicyAttachmentResourceType, resourceaws.AwsIamRoleResourceType), alerts.EnumerationPhase)).Return()
 			},
 		},
 		{
 			test:    "Cannot list roles policy attachment",
 			dirName: "aws_iam_role_policy_attachment_empty",
-			mocks: func(repo *repository.MockIAMRepository) {
-				repo.On("ListAllRoles").Once().Return([]*iam.Role{}, nil)
-				repo.On("ListAllRolePolicyAttachments", mock.Anything).Return(nil, awserr.NewRequestFailure(nil, 403, ""))
+			mocks: func(repo *repository.MockIAMRepository, alerter *mocks.AlerterInterface) {
+				repo.On("ListAllRoles").Once().Return([]*iam.Role{{RoleName: aws.String("test")}}, nil)
+				awsError := awserr.NewRequestFailure(awserr.New("AccessDeniedException", "", errors.New("")), 403, "")
+				repo.On("ListAllRolePolicyAttachments", mock.Anything).Return(nil, awsError)
+
+				alerter.On("SendAlert", resourceaws.AwsIamRolePolicyAttachmentResourceType, alerts.NewRemoteAccessDeniedAlert(common.RemoteAWSTerraform, remoteerr.NewResourceListingErrorWithType(awsError, resourceaws.AwsIamRolePolicyAttachmentResourceType, resourceaws.AwsIamRolePolicyAttachmentResourceType), alerts.EnumerationPhase)).Return()
 			},
 		},
 	}
@@ -612,9 +641,9 @@ func TestIamRolePolicyAttachment(t *testing.T) {
 
 			// Initialize mocks
 			alerter := &mocks.AlerterInterface{}
-			alerter.On("SendAlert", mock.Anything, mock.Anything).Maybe().Return()
 			fakeRepo := &repository.MockIAMRepository{}
-			c.mocks(fakeRepo)
+			c.mocks(fakeRepo, alerter)
+
 			var repo repository.IAMRepository = fakeRepo
 			providerVersion := "3.19.0"
 			realProvider, err := terraform2.InitTestAwsProvider(providerLibrary, providerVersion)
@@ -635,7 +664,7 @@ func TestIamRolePolicyAttachment(t *testing.T) {
 			}
 
 			remoteLibrary.AddEnumerator(remoteaws.NewIamRolePolicyAttachmentEnumerator(repo, factory))
-			remoteLibrary.AddDetailsFetcher(resourceaws.AwsIamRolePolicyAttachmentResourceType, remoteaws.NewIamRolePolicyAttachmentDetailsFetcher(provider, deserializer))
+			remoteLibrary.AddDetailsFetcher(resourceaws.AwsIamRolePolicyAttachmentResourceType, common.NewGenericDetailsFetcher(resourceaws.AwsIamRolePolicyAttachmentResourceType, provider, deserializer))
 
 			testFilter := &filter.MockFilter{}
 			testFilter.On("IsTypeIgnored", mock.Anything).Return(false)
@@ -647,6 +676,8 @@ func TestIamRolePolicyAttachment(t *testing.T) {
 				return
 			}
 			test.TestAgainstGoldenFile(got, resourceaws.AwsIamRolePolicyAttachmentResourceType, c.dirName, provider, deserializer, shouldUpdate, tt)
+			alerter.AssertExpectations(tt)
+			fakeRepo.AssertExpectations(tt)
 		})
 	}
 }
@@ -656,13 +687,13 @@ func TestIamAccessKey(t *testing.T) {
 	cases := []struct {
 		test    string
 		dirName string
-		mocks   func(repo *repository.MockIAMRepository)
+		mocks   func(*repository.MockIAMRepository, *mocks.AlerterInterface)
 		wantErr error
 	}{
 		{
 			test:    "no iam access_key",
 			dirName: "iam_access_key_empty",
-			mocks: func(repo *repository.MockIAMRepository) {
+			mocks: func(repo *repository.MockIAMRepository, alerter *mocks.AlerterInterface) {
 				users := []*iam.User{
 					{
 						UserName: aws.String("test-driftctl"),
@@ -676,7 +707,7 @@ func TestIamAccessKey(t *testing.T) {
 		{
 			test:    "iam multiples keys for multiples users",
 			dirName: "iam_access_key_multiple",
-			mocks: func(repo *repository.MockIAMRepository) {
+			mocks: func(repo *repository.MockIAMRepository, alerter *mocks.AlerterInterface) {
 				users := []*iam.User{
 					{
 						UserName: aws.String("test-driftctl"),
@@ -707,17 +738,23 @@ func TestIamAccessKey(t *testing.T) {
 		{
 			test:    "Cannot list iam user",
 			dirName: "iam_access_key_empty",
-			mocks: func(repo *repository.MockIAMRepository) {
-				repo.On("ListAllUsers").Once().Return(nil, awserr.NewRequestFailure(nil, 403, ""))
+			mocks: func(repo *repository.MockIAMRepository, alerter *mocks.AlerterInterface) {
+				awsError := awserr.NewRequestFailure(awserr.New("AccessDeniedException", "", errors.New("")), 403, "")
+				repo.On("ListAllUsers").Once().Return(nil, awsError)
+
+				alerter.On("SendAlert", resourceaws.AwsIamAccessKeyResourceType, alerts.NewRemoteAccessDeniedAlert(common.RemoteAWSTerraform, remoteerr.NewResourceListingErrorWithType(awsError, resourceaws.AwsIamAccessKeyResourceType, resourceaws.AwsIamUserResourceType), alerts.EnumerationPhase)).Return()
 			},
 			wantErr: nil,
 		},
 		{
 			test:    "Cannot list iam access_key",
 			dirName: "iam_access_key_empty",
-			mocks: func(repo *repository.MockIAMRepository) {
+			mocks: func(repo *repository.MockIAMRepository, alerter *mocks.AlerterInterface) {
 				repo.On("ListAllUsers").Once().Return([]*iam.User{}, nil)
-				repo.On("ListAllAccessKeys", mock.Anything).Return(nil, awserr.NewRequestFailure(nil, 403, ""))
+				awsError := awserr.NewRequestFailure(awserr.New("AccessDeniedException", "", errors.New("")), 403, "")
+				repo.On("ListAllAccessKeys", mock.Anything).Return(nil, awsError)
+
+				alerter.On("SendAlert", resourceaws.AwsIamAccessKeyResourceType, alerts.NewRemoteAccessDeniedAlert(common.RemoteAWSTerraform, remoteerr.NewResourceListingErrorWithType(awsError, resourceaws.AwsIamAccessKeyResourceType, resourceaws.AwsIamAccessKeyResourceType), alerts.EnumerationPhase)).Return()
 			},
 			wantErr: nil,
 		},
@@ -742,9 +779,9 @@ func TestIamAccessKey(t *testing.T) {
 
 			// Initialize mocks
 			alerter := &mocks.AlerterInterface{}
-			alerter.On("SendAlert", mock.Anything, mock.Anything).Maybe().Return()
 			fakeRepo := &repository.MockIAMRepository{}
-			c.mocks(fakeRepo)
+			c.mocks(fakeRepo, alerter)
+
 			var repo repository.IAMRepository = fakeRepo
 			providerVersion := "3.19.0"
 			realProvider, err := terraform2.InitTestAwsProvider(providerLibrary, providerVersion)
@@ -765,7 +802,7 @@ func TestIamAccessKey(t *testing.T) {
 			}
 
 			remoteLibrary.AddEnumerator(remoteaws.NewIamAccessKeyEnumerator(repo, factory))
-			remoteLibrary.AddDetailsFetcher(resourceaws.AwsIamAccessKeyResourceType, remoteaws.NewIamAccessKeyDetailsFetcher(provider, deserializer))
+			remoteLibrary.AddDetailsFetcher(resourceaws.AwsIamAccessKeyResourceType, common.NewGenericDetailsFetcher(resourceaws.AwsIamAccessKeyResourceType, provider, deserializer))
 
 			testFilter := &filter.MockFilter{}
 			testFilter.On("IsTypeIgnored", mock.Anything).Return(false)
@@ -777,6 +814,8 @@ func TestIamAccessKey(t *testing.T) {
 				return
 			}
 			test.TestAgainstGoldenFile(got, resourceaws.AwsIamAccessKeyResourceType, c.dirName, provider, deserializer, shouldUpdate, tt)
+			alerter.AssertExpectations(tt)
+			fakeRepo.AssertExpectations(tt)
 		})
 	}
 }
@@ -786,13 +825,13 @@ func TestIamUserPolicyAttachment(t *testing.T) {
 	cases := []struct {
 		test    string
 		dirName string
-		mocks   func(repo *repository.MockIAMRepository)
+		mocks   func(*repository.MockIAMRepository, *mocks.AlerterInterface)
 		wantErr error
 	}{
 		{
 			test:    "no iam user policy",
 			dirName: "iam_user_policy_empty",
-			mocks: func(repo *repository.MockIAMRepository) {
+			mocks: func(repo *repository.MockIAMRepository, alerter *mocks.AlerterInterface) {
 				users := []*iam.User{
 					{
 						UserName: aws.String("loadbalancer"),
@@ -806,7 +845,7 @@ func TestIamUserPolicyAttachment(t *testing.T) {
 		{
 			test:    "iam multiples users multiple policies",
 			dirName: "iam_user_policy_attachment_multiple",
-			mocks: func(repo *repository.MockIAMRepository) {
+			mocks: func(repo *repository.MockIAMRepository, alerter *mocks.AlerterInterface) {
 				users := []*iam.User{
 					{
 						UserName: aws.String("loadbalancer"),
@@ -912,17 +951,23 @@ func TestIamUserPolicyAttachment(t *testing.T) {
 		{
 			test:    "cannot list user",
 			dirName: "iam_user_policy_empty",
-			mocks: func(repo *repository.MockIAMRepository) {
-				repo.On("ListAllUsers").Return(nil, awserr.NewRequestFailure(nil, 403, ""))
+			mocks: func(repo *repository.MockIAMRepository, alerter *mocks.AlerterInterface) {
+				awsError := awserr.NewRequestFailure(awserr.New("AccessDeniedException", "", errors.New("")), 403, "")
+				repo.On("ListAllUsers").Return(nil, awsError)
+
+				alerter.On("SendAlert", resourceaws.AwsIamUserPolicyAttachmentResourceType, alerts.NewRemoteAccessDeniedAlert(common.RemoteAWSTerraform, remoteerr.NewResourceListingErrorWithType(awsError, resourceaws.AwsIamUserPolicyAttachmentResourceType, resourceaws.AwsIamUserResourceType), alerts.EnumerationPhase)).Return()
 			},
 			wantErr: nil,
 		},
 		{
 			test:    "cannot list user policies attachment",
 			dirName: "iam_user_policy_empty",
-			mocks: func(repo *repository.MockIAMRepository) {
+			mocks: func(repo *repository.MockIAMRepository, alerter *mocks.AlerterInterface) {
 				repo.On("ListAllUsers").Once().Return([]*iam.User{}, nil)
-				repo.On("ListAllUserPolicyAttachments", mock.Anything).Return(nil, awserr.NewRequestFailure(nil, 403, ""))
+				awsError := awserr.NewRequestFailure(awserr.New("AccessDeniedException", "", errors.New("")), 403, "")
+				repo.On("ListAllUserPolicyAttachments", mock.Anything).Return(nil, awsError)
+
+				alerter.On("SendAlert", resourceaws.AwsIamUserPolicyAttachmentResourceType, alerts.NewRemoteAccessDeniedAlert(common.RemoteAWSTerraform, remoteerr.NewResourceListingErrorWithType(awsError, resourceaws.AwsIamUserPolicyAttachmentResourceType, resourceaws.AwsIamUserPolicyAttachmentResourceType), alerts.EnumerationPhase)).Return()
 			},
 			wantErr: nil,
 		},
@@ -947,9 +992,9 @@ func TestIamUserPolicyAttachment(t *testing.T) {
 
 			// Initialize mocks
 			alerter := &mocks.AlerterInterface{}
-			alerter.On("SendAlert", mock.Anything, mock.Anything).Maybe().Return()
 			fakeRepo := &repository.MockIAMRepository{}
-			c.mocks(fakeRepo)
+			c.mocks(fakeRepo, alerter)
+
 			var repo repository.IAMRepository = fakeRepo
 			providerVersion := "3.19.0"
 			realProvider, err := terraform2.InitTestAwsProvider(providerLibrary, providerVersion)
@@ -970,7 +1015,7 @@ func TestIamUserPolicyAttachment(t *testing.T) {
 			}
 
 			remoteLibrary.AddEnumerator(remoteaws.NewIamUserPolicyAttachmentEnumerator(repo, factory))
-			remoteLibrary.AddDetailsFetcher(resourceaws.AwsIamUserPolicyAttachmentResourceType, remoteaws.NewIamUserPolicyAttachmentDetailsFetcher(provider, deserializer))
+			remoteLibrary.AddDetailsFetcher(resourceaws.AwsIamUserPolicyAttachmentResourceType, common.NewGenericDetailsFetcher(resourceaws.AwsIamUserPolicyAttachmentResourceType, provider, deserializer))
 
 			testFilter := &filter.MockFilter{}
 			testFilter.On("IsTypeIgnored", mock.Anything).Return(false)
@@ -982,6 +1027,8 @@ func TestIamUserPolicyAttachment(t *testing.T) {
 				return
 			}
 			test.TestAgainstGoldenFile(got, resourceaws.AwsIamUserPolicyAttachmentResourceType, c.dirName, provider, deserializer, shouldUpdate, tt)
+			alerter.AssertExpectations(tt)
+			fakeRepo.AssertExpectations(tt)
 		})
 	}
 }
@@ -991,13 +1038,13 @@ func TestIamRolePolicy(t *testing.T) {
 	cases := []struct {
 		test    string
 		dirName string
-		mocks   func(repo *repository.MockIAMRepository)
+		mocks   func(*repository.MockIAMRepository, *mocks.AlerterInterface)
 		wantErr error
 	}{
 		{
 			test:    "no iam role policy",
 			dirName: "iam_role_policy_empty",
-			mocks: func(repo *repository.MockIAMRepository) {
+			mocks: func(repo *repository.MockIAMRepository, alerter *mocks.AlerterInterface) {
 				roles := []*iam.Role{
 					{
 						RoleName: aws.String("test_role"),
@@ -1011,7 +1058,7 @@ func TestIamRolePolicy(t *testing.T) {
 		{
 			test:    "multiples roles with inline policies",
 			dirName: "iam_role_policy_multiple",
-			mocks: func(repo *repository.MockIAMRepository) {
+			mocks: func(repo *repository.MockIAMRepository, alerter *mocks.AlerterInterface) {
 				roles := []*iam.Role{
 					{
 						RoleName: aws.String("test_role_0"),
@@ -1035,17 +1082,23 @@ func TestIamRolePolicy(t *testing.T) {
 		{
 			test:    "Cannot list roles",
 			dirName: "iam_role_policy_empty",
-			mocks: func(repo *repository.MockIAMRepository) {
-				repo.On("ListAllRoles").Once().Return(nil, awserr.NewRequestFailure(nil, 403, ""))
+			mocks: func(repo *repository.MockIAMRepository, alerter *mocks.AlerterInterface) {
+				awsError := awserr.NewRequestFailure(awserr.New("AccessDeniedException", "", errors.New("")), 403, "")
+				repo.On("ListAllRoles").Once().Return(nil, awsError)
+
+				alerter.On("SendAlert", resourceaws.AwsIamRolePolicyResourceType, alerts.NewRemoteAccessDeniedAlert(common.RemoteAWSTerraform, remoteerr.NewResourceListingErrorWithType(awsError, resourceaws.AwsIamRolePolicyResourceType, resourceaws.AwsIamRoleResourceType), alerts.EnumerationPhase)).Return()
 			},
 			wantErr: nil,
 		},
 		{
 			test:    "cannot list role policy",
 			dirName: "iam_role_policy_empty",
-			mocks: func(repo *repository.MockIAMRepository) {
+			mocks: func(repo *repository.MockIAMRepository, alerter *mocks.AlerterInterface) {
 				repo.On("ListAllRoles").Once().Return([]*iam.Role{}, nil)
-				repo.On("ListAllRolePolicies", mock.Anything).Return(nil, awserr.NewRequestFailure(nil, 403, ""))
+				awsError := awserr.NewRequestFailure(awserr.New("AccessDeniedException", "", errors.New("")), 403, "")
+				repo.On("ListAllRolePolicies", mock.Anything).Return(nil, awsError)
+
+				alerter.On("SendAlert", resourceaws.AwsIamRolePolicyResourceType, alerts.NewRemoteAccessDeniedAlert(common.RemoteAWSTerraform, remoteerr.NewResourceListingErrorWithType(awsError, resourceaws.AwsIamRolePolicyResourceType, resourceaws.AwsIamRolePolicyResourceType), alerts.EnumerationPhase)).Return()
 			},
 			wantErr: nil,
 		},
@@ -1070,9 +1123,9 @@ func TestIamRolePolicy(t *testing.T) {
 
 			// Initialize mocks
 			alerter := &mocks.AlerterInterface{}
-			alerter.On("SendAlert", mock.Anything, mock.Anything).Maybe().Return()
 			fakeRepo := &repository.MockIAMRepository{}
-			c.mocks(fakeRepo)
+			c.mocks(fakeRepo, alerter)
+
 			var repo repository.IAMRepository = fakeRepo
 			providerVersion := "3.19.0"
 			realProvider, err := terraform2.InitTestAwsProvider(providerLibrary, providerVersion)
@@ -1100,11 +1153,13 @@ func TestIamRolePolicy(t *testing.T) {
 
 			s := NewScanner(remoteLibrary, alerter, scanOptions, testFilter)
 			got, err := s.Resources()
-			assert.Equal(tt, err, c.wantErr)
+			assert.Equal(tt, c.wantErr, err)
 			if err != nil {
 				return
 			}
 			test.TestAgainstGoldenFile(got, resourceaws.AwsIamRolePolicyResourceType, c.dirName, provider, deserializer, shouldUpdate, tt)
+			alerter.AssertExpectations(tt)
+			fakeRepo.AssertExpectations(tt)
 		})
 	}
 }
