@@ -7,7 +7,7 @@ import (
 const AwsKeyPairResourceType = "aws_key_pair"
 
 func initAwsKeyPairMetaData(resourceSchemaRepository resource.SchemaRepositoryInterface) {
-	resourceSchemaRepository.SetNormalizeFunc(AwsKeyPairResourceType, func(res *resource.AbstractResource) {
+	resourceSchemaRepository.SetNormalizeFunc(AwsKeyPairResourceType, func(res *resource.Resource) {
 		val := res.Attrs
 		val.SafeDelete([]string{"key_name_prefix"})
 		val.SafeDelete([]string{"public_key"})
