@@ -7,7 +7,7 @@ import (
 const AwsRoute53RecordResourceType = "aws_route53_record"
 
 func initAwsRoute53RecordMetaData(resourceSchemaRepository resource.SchemaRepositoryInterface) {
-	resourceSchemaRepository.SetNormalizeFunc(AwsRoute53RecordResourceType, func(res *resource.AbstractResource) {
+	resourceSchemaRepository.SetNormalizeFunc(AwsRoute53RecordResourceType, func(res *resource.Resource) {
 		val := res.Attrs
 		val.DeleteIfDefault("health_check_id")
 		val.DeleteIfDefault("set_identifier")
@@ -15,7 +15,7 @@ func initAwsRoute53RecordMetaData(resourceSchemaRepository resource.SchemaReposi
 		val.SafeDelete([]string{"name"})
 		val.SafeDelete([]string{"allow_overwrite"})
 	})
-	resourceSchemaRepository.SetHumanReadableAttributesFunc(AwsRoute53RecordResourceType, func(res *resource.AbstractResource) map[string]string {
+	resourceSchemaRepository.SetHumanReadableAttributesFunc(AwsRoute53RecordResourceType, func(res *resource.Resource) map[string]string {
 		val := res.Attrs
 		attrs := make(map[string]string)
 		if fqdn := val.GetString("fqdn"); fqdn != nil && *fqdn != "" {
