@@ -5,7 +5,14 @@ import "github.com/cloudskiff/driftctl/pkg/resource"
 const AwsRouteTableAssociationResourceType = "aws_route_table_association"
 
 func initAwsRouteTableAssociationMetaData(resourceSchemaRepository resource.SchemaRepositoryInterface) {
-	resourceSchemaRepository.SetHumanReadableAttributesFunc(AwsRouteTableAssociationResourceType, func(res *resource.AbstractResource) map[string]string {
+
+	resourceSchemaRepository.SetResolveReadAttributesFunc(AwsRouteTableAssociationResourceType, func(res *resource.Resource) map[string]string {
+		return map[string]string{
+			"route_table_id": *res.Attributes().GetString("route_table_id"),
+		}
+	})
+
+	resourceSchemaRepository.SetHumanReadableAttributesFunc(AwsRouteTableAssociationResourceType, func(res *resource.Resource) map[string]string {
 		val := res.Attrs
 		attrs := make(map[string]string)
 		if rtID := val.GetString("route_table_id"); rtID != nil && *rtID != "" {
