@@ -5,6 +5,11 @@ import "github.com/cloudskiff/driftctl/pkg/resource"
 const AwsSnsTopicResourceType = "aws_sns_topic"
 
 func initSnsTopicMetaData(resourceSchemaRepository resource.SchemaRepositoryInterface) {
+	resourceSchemaRepository.SetResolveReadAttributesFunc(AwsSnsTopicResourceType, func(res *resource.Resource) map[string]string {
+		return map[string]string{
+			"topic_arn": res.ResourceId(),
+		}
+	})
 	resourceSchemaRepository.UpdateSchema(AwsSnsTopicResourceType, map[string]func(attributeSchema *resource.AttributeSchema){
 		"delivery_policy": func(attributeSchema *resource.AttributeSchema) {
 			attributeSchema.JsonString = true
@@ -13,7 +18,7 @@ func initSnsTopicMetaData(resourceSchemaRepository resource.SchemaRepositoryInte
 			attributeSchema.JsonString = true
 		},
 	})
-	resourceSchemaRepository.SetNormalizeFunc(AwsSnsTopicResourceType, func(res *resource.AbstractResource) {
+	resourceSchemaRepository.SetNormalizeFunc(AwsSnsTopicResourceType, func(res *resource.Resource) {
 		val := res.Attrs
 		val.DeleteIfDefault("sqs_success_feedback_sample_rate")
 		val.DeleteIfDefault("lambda_success_feedback_sample_rate")
@@ -24,7 +29,7 @@ func initSnsTopicMetaData(resourceSchemaRepository resource.SchemaRepositoryInte
 		val.SafeDelete([]string{"name_prefix"})
 		val.SafeDelete([]string{"owner"})
 	})
-	resourceSchemaRepository.SetHumanReadableAttributesFunc(AwsSnsTopicResourceType, func(res *resource.AbstractResource) map[string]string {
+	resourceSchemaRepository.SetHumanReadableAttributesFunc(AwsSnsTopicResourceType, func(res *resource.Resource) map[string]string {
 		val := res.Attrs
 		attrs := make(map[string]string)
 		if name := val.GetString("name"); name != nil && *name != "" {
