@@ -8,13 +8,19 @@ import (
 const AwsSnsTopicPolicyResourceType = "aws_sns_topic_policy"
 
 func initSnsTopicPolicyMetaData(resourceSchemaRepository resource.SchemaRepositoryInterface) {
+	resourceSchemaRepository.SetResolveReadAttributesFunc(AwsSnsTopicPolicyResourceType, func(res *resource.Resource) map[string]string {
+		return map[string]string{
+			"topic_arn": res.ResourceId(),
+		}
+	})
+
 	resourceSchemaRepository.UpdateSchema(AwsSnsTopicPolicyResourceType, map[string]func(attributeSchema *resource.AttributeSchema){
 		"policy": func(attributeSchema *resource.AttributeSchema) {
 			attributeSchema.JsonString = true
 		},
 	})
 
-	resourceSchemaRepository.SetNormalizeFunc(AwsSnsTopicPolicyResourceType, func(res *resource.AbstractResource) {
+	resourceSchemaRepository.SetNormalizeFunc(AwsSnsTopicPolicyResourceType, func(res *resource.Resource) {
 		val := res.Attrs
 		val.SafeDelete([]string{"owner"})
 		jsonString, err := helpers.NormalizeJsonString((*val)["policy"])
