@@ -8,6 +8,12 @@ import (
 const AwsSnsTopicSubscriptionResourceType = "aws_sns_topic_subscription"
 
 func initSnsTopicSubscriptionMetaData(resourceSchemaRepository resource.SchemaRepositoryInterface) {
+	resourceSchemaRepository.SetResolveReadAttributesFunc(AwsSnsTopicSubscriptionResourceType, func(res *resource.Resource) map[string]string {
+		return map[string]string{
+			"SubscriptionId": res.ResourceId(),
+		}
+	})
+
 	resourceSchemaRepository.UpdateSchema(AwsSnsTopicSubscriptionResourceType, map[string]func(attributeSchema *resource.AttributeSchema){
 		"delivery_policy": func(attributeSchema *resource.AttributeSchema) {
 			attributeSchema.JsonString = true
@@ -17,7 +23,7 @@ func initSnsTopicSubscriptionMetaData(resourceSchemaRepository resource.SchemaRe
 		},
 	})
 
-	resourceSchemaRepository.SetNormalizeFunc(AwsSnsTopicSubscriptionResourceType, func(res *resource.AbstractResource) {
+	resourceSchemaRepository.SetNormalizeFunc(AwsSnsTopicSubscriptionResourceType, func(res *resource.Resource) {
 		val := res.Attrs
 		jsonString, err := helpers.NormalizeJsonString((*val)["delivery_policy"])
 		if err == nil {
