@@ -9,6 +9,7 @@ func InitResourcesMetadata(resourceSchemaRepository resource.SchemaRepositoryInt
 	initAwsDbSubnetGroupMetaData(resourceSchemaRepository)
 	initAwsDefaultSecurityGroupMetaData(resourceSchemaRepository)
 	initAwsDefaultSubnetMetaData(resourceSchemaRepository)
+	initAwsDefaultRouteTableMetadata(resourceSchemaRepository)
 	initAwsDynamodbTableMetaData(resourceSchemaRepository)
 	initAwsEbsSnapshotMetaData(resourceSchemaRepository)
 	initAwsInstanceMetaData(resourceSchemaRepository)
@@ -16,6 +17,10 @@ func InitResourcesMetadata(resourceSchemaRepository resource.SchemaRepositoryInt
 	initAwsEipMetaData(resourceSchemaRepository)
 	initAwsS3BucketMetaData(resourceSchemaRepository)
 	initAwsS3BucketPolicyMetaData(resourceSchemaRepository)
+	initAwsS3BucketInventoryMetadata(resourceSchemaRepository)
+	initAwsS3BucketMetricMetadata(resourceSchemaRepository)
+	initAwsS3BucketNotificationMetadata(resourceSchemaRepository)
+	initAwsS3BucketAnalyticsConfigurationMetaData(resourceSchemaRepository)
 	initAwsEcrRepositoryMetaData(resourceSchemaRepository)
 	initAwsRouteMetaData(resourceSchemaRepository)
 	initAwsRouteTableAssociationMetaData(resourceSchemaRepository)
@@ -30,6 +35,8 @@ func InitResourcesMetadata(resourceSchemaRepository resource.SchemaRepositoryInt
 	initAwsIAMPolicyAttachmentMetaData(resourceSchemaRepository)
 	initAwsIAMRoleMetaData(resourceSchemaRepository)
 	initAwsIAMRolePolicyMetaData(resourceSchemaRepository)
+	initAwsIamRolePolicyAttachmentMetaData(resourceSchemaRepository)
+	initAwsIamUserPolicyAttachmentMetaData(resourceSchemaRepository)
 	initAwsIAMUserMetaData(resourceSchemaRepository)
 	initAwsIAMUserPolicyMetaData(resourceSchemaRepository)
 	initAwsKeyPairMetaData(resourceSchemaRepository)
