@@ -1,15 +1,13 @@
 package terraform
 
 import (
-	"strings"
-
-	"github.com/pkg/errors"
 	"github.com/sirupsen/logrus"
 )
 
 const (
 	AWS    string = "aws"
 	GITHUB string = "github"
+	GOOGLE string = "google"
 )
 
 type ProviderLibrary struct {
@@ -40,22 +38,3 @@ func (p *ProviderLibrary) Cleanup() {
 		provider.Cleanup()
 	}
 }
-
-func (p *ProviderLibrary) GetProviderForResourceType(resType string) (TerraformProvider, error) {
-
-	var name string
-
-	if strings.HasPrefix(resType, AWS) {
-		name = AWS
-	}
-
-	if strings.HasPrefix(resType, GITHUB) {
-		name = GITHUB
-	}
-
-	if name != "" {
-		return p.Provider(name), nil
-	}
-
-	return nil, errors.New("Unable to resolve provider for resource")
-}
