@@ -6,6 +6,7 @@ import (
 	"github.com/cloudskiff/driftctl/pkg/output"
 	"github.com/cloudskiff/driftctl/pkg/remote/aws"
 	"github.com/cloudskiff/driftctl/pkg/remote/github"
+	"github.com/cloudskiff/driftctl/pkg/remote/google"
 	"github.com/cloudskiff/driftctl/pkg/terraform"
 )
 
@@ -31,3 +32,15 @@ func InitTestGithubProvider(providerLibrary *terraform.ProviderLibrary, version
 
 	return provider, nil
 }
+
+func InitTestGoogleProvider(providerLibrary *terraform.ProviderLibrary, version string) (*google.GCPTerraformProvider, error) {
+	progress := &output.MockProgress{}
+	progress.On("Inc").Maybe().Return()
+	provider, err := google.NewGCPTerraformProvider(version, progress, "")
+	if err != nil {
+		return nil, err
+	}
+	providerLibrary.AddProvider(terraform.GOOGLE, provider)
+
+	return provider, nil
+}
